@@ -2,26 +2,30 @@ import random
 
 from .enums.difficulty import Difficulty
 from .enums.goal import Goal
+from .enums.statue_req import StatueReq
 from .enums.logic import Logic
 from .enums.entrance_shuffle import EntranceShuffle
 from .enums.enemizer import Enemizer
 from .enums.start_location import StartLocation
+from .enums.sprites import Sprite
 #from .enums.level import Level
 
 
 class RandomizerData:
     def __init__(self, seed: int = random.randint(0, 999999999),
-                 difficulty: Difficulty = Difficulty.NORMAL, goal: Goal = Goal.DARK_GAIA,
-                 logic: Logic = Logic.COMPLETABLE, statues: str = "4", enemizer: Enemizer = Enemizer.NONE,
+                 difficulty: Difficulty = Difficulty.NORMAL, goal: Goal = Goal.DARK_GAIA, logic: Logic = Logic.COMPLETABLE,
+                 statues: str = "4", statue_req: StatueReq = StatueReq.GAME_CHOICE, enemizer: Enemizer = Enemizer.NONE,
                  start_location: StartLocation = StartLocation.SOUTH_CAPE, firebird: bool = False, ohko: bool = False,
                  red_jewel_madness: bool = False, allow_glitches: bool = False, boss_shuffle: bool = False,
-                 open_mode: bool = False, z3: bool = False, overworld_shuffle: bool = False, entrance_shuffle: EntranceShuffle = EntranceShuffle.NONE, race_mode: bool = False,
-                 dungeon_shuffle: bool = False):
+                 open_mode: bool = False, z3: bool = False, overworld_shuffle: bool = False,
+                 entrance_shuffle: EntranceShuffle = EntranceShuffle.NONE, race_mode: bool = False, fluteless: bool = False,
+                 sprite: Sprite = Sprite.WILL, dungeon_shuffle: bool = False):
         self.seed = seed
         self.difficulty = difficulty
 #        self.level = level
         self.start_location = start_location
         self.goal = goal
+        self.statue_req = statue_req
         self.logic = logic
         self.statues = statues
         self.enemizer = enemizer
@@ -37,3 +41,5 @@ class RandomizerData:
         self.overworld_shuffle = overworld_shuffle
         self.entrance_shuffle = entrance_shuffle
         self.race_mode = race_mode
+        self.fluteless = fluteless
+        self.sprite = sprite
